@@ -19,8 +19,6 @@
 from base64 import b64encode
 from copy import deepcopy
 
-from six import text_type
-
 from cubicweb import ValidationError
 from cubicweb.devtools.testlib import CubicWebTC
 
@@ -112,7 +110,7 @@ class IJSONSchemaETypeAdapterTC(CubicWebTC):
         user_creation_schema = creation_schema['properties']
         expected_items = {
             'type': 'string',
-            'oneOf': [{'enum': [text_type(eid)], 'title': title}
+            'oneOf': [{'enum': [str(eid)], 'title': title}
                       for eid, title in groups],
         }
         self.assertEqual(user_creation_schema['in_group']['items'],
@@ -298,7 +296,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
             users = cnx.find('CWGroup', name=u'users').one()
             adapter = jsonschema_adapter(cnx, etype='CWUser')
             instance = {'login': 'bob', 'upassword': 'sponge',
-                        'in_group': [text_type(users.eid)],
+                        'in_group': [str(users.eid)],
                         'use_email': [{'address': 'bob@sponge.com'}]}
             entity = adapter.create_entity(instance)
             self.assertEqual(entity.login, 'bob')
@@ -317,7 +315,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
             adapter = jsonschema_adapter(cnx, entity=entity)
 
             instance = {'login': 'bobby',
-                        'in_group': [text_type(users.eid)],
+                        'in_group': [str(users.eid)],
                         'use_email': [{'address': 'bob@sponge.com'}]}
             adapter.edit_entity(instance)
             entity.cw_clear_all_caches()
@@ -331,8 +329,8 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
             self.assertEqual(entity.use_email[0].address, 'bob@sponge.com')
 
             instance = {'login': 'bobby',
-                        'in_group': [text_type(users.eid),
-                                     text_type(guests.eid)],
+                        'in_group': [str(users.eid),
+                                     str(guests.eid)],
                         'use_email': [{'address': 'bobby@sponge.com'}]}
             adapter.edit_entity(instance)
             entity.cw_clear_all_caches()
@@ -344,7 +342,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
             self.assertEqual(entity.use_email[0].address, 'bobby@sponge.com')
 
             instance = {'login': 'bobby',
-                        'in_group': [text_type(users.eid)],
+                        'in_group': [str(users.eid)],
                         'use_email': [{'address': 'bobby@sponge.com'},
                                       {'address': 'bob.sponge@sponge.com'}]}
             adapter.edit_entity(instance)
@@ -356,7 +354,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
                                   ['bobby@sponge.com', 'bob.sponge@sponge.com'])
 
             instance = {'login': 'bobby',
-                        'in_group': [text_type(users.eid)],
+                        'in_group': [str(users.eid)],
                         'use_email': [{'address': 'bob.sponge@sponge.com'}]}
             adapter.edit_entity(instance)
             entity.cw_clear_all_caches()
@@ -366,7 +364,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
 
             entity.cw_set(use_email=cnx.create_entity('EmailAlias'))
             instance = {'login': 'bobby',
-                        'in_group': [text_type(users.eid)],
+                        'in_group': [str(users.eid)],
                         'use_email': []}
             adapter.edit_entity(instance)
             entity.cw_clear_all_caches()
@@ -385,7 +383,7 @@ class IJSONSchemaEntityAdapterTC(CubicWebTC):
             email.cw_clear_all_caches()
 
             groups = entity.related('in_group', 'subject').entities()
-            group_ids = [text_type(group.eid) for group in groups]
+            group_ids = [str(group.eid) for group in groups]
             expected = {
                 u'firstname': u'Bob',
                 u'login': u'bob',
