@@ -136,6 +136,7 @@ class RelationMapperTC(CubicWebTC):
                     {'enum': ['png'], 'title': 'png', 'type': 'string'},
                 ],
                 'default': 'png',
+                'title': 'media_type',
             }
             self.assertEqual(field.get_schema(), expected)
             adapter = self.vreg['adapters'].select(
@@ -692,7 +693,6 @@ class EntityMapperTC(CubicWebTC):
             expected['definitions']['EXIF data']['required'] = ['flash']
             expected['properties']['media_type']['default'] = 'png'
             del expected['properties']['media_type']['type']
-            del expected['properties']['media_type']['title']
             expected['properties']['media_type']['oneOf'] = [
                 {'enum': ['jpeg'], 'title': 'jpeg', 'type': 'string'},
                 {'enum': ['png'], 'title': 'png', 'type': 'string'},
